require 'payoneer/configuration'
require 'httparty'

module Payoneer
  class Request
    include HTTParty

    def execute(method_name, response_klass, params = {})
      configure_security
      response = self.class.post(api_url, :query => {:mname => method_name}, :body => params)
      response_klass.new(response.body)
    end

    private

    def api_url
      ['https://', host, '/payouts/HttpApi/Api.aspx'].join
    end

    def host
      sandbox = config.environment.eql?(:production) ? nil : 'sandbox'
      sub_domain = config.client_cert ? 'apicert' : 'api'

      [sub_domain, sandbox, 'payoneer.com'].compact.join('.')
    end

    def configure_security
      self.class.pkcs12(File.read(config.client_cert), config.client_cert_passwd) if config.client_cert
    end

    def config
      Payoneer::Configuration
    end
  end
end
